import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/wenleicao/24da06aff2538ba8740e559c7e670257/raw/ad738fc0f69f246ac2e71b8e74d2d4a60f0b2887/city_crime_population_ratio.csv';

const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 20, left: 50 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.Crime_Ratio = +d['crime_rate'];
      return d;
    };

    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  //console.log(data[0]);
   const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleLinear()
    .domain([0, max(data, d => d.Crime_Ratio)])
   // .range([0, innerHeight]);   //original [0, innerHeight], need to show bigger number up
     .range([innerHeight, 0]); 
 

  const xScale = scaleBand()
    .domain(data.map(d => d.City))
    .range([0, innerWidth]);
 //console.log(yScale.ticks());
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${-margin.bottom})`}>
        {yScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(0, ${yScale(tickValue)})`}>
            <line x2={innerWidth} stroke="black" />
            <text style={{ textAnchor: 'end' }} x={-3} dy=".32em">
              {tickValue}
            </text>
          </g>
        ))}
        
      {xScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'middle' }}
           // attr ={{transform:'rotate(-65)'}}
            dy=".71em"
            y={innerHeight + margin.top + 25}
            x={xScale(tickValue) + xScale.bandwidth() / 2}
          >
            {tickValue }
          </text>
        ))}

        {data.map(d => (
          <rect
            x={xScale(d.City)} //add margin left to leave space for y axis
            y={yScale(d.Crime_Ratio)} //minus the bottom so that it can leave room for x axis
            width={xScale.bandwidth()}
            height={height - yScale(d.Crime_Ratio)}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
